==> calibre_7.0.0%2Bds.orig.tar.xz: calibre-7.0.0/src/odf/thumbnail.py <==
#!/usr/bin/env python
# This contains a 128x128 px thumbnail in PNG format
# Taken from https://cgit.freedesktop.org/libreoffice/core/tree/sysui/desktop/icons/hicolor/128x128/apps/main.png
# License: GPL-3
import base64

iconstr = b"""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==
"""


def thumbnail():
    icon = base64.decodestring(iconstr)
    return icon


if __name__ == "__main__":
    icon = thumbnail()
    f = open("thumbnail.png","wb")
    f.write(icon)
    f.close()

==> calibre_7.26.0%2Bds.orig.tar.xz: calibre-7.26.0/src/odf/thumbnail.py <==
#!/usr/bin/env python
# This contains a 128x128 px thumbnail in PNG format
# Taken from https://cgit.freedesktop.org/libreoffice/core/tree/sysui/desktop/icons/hicolor/128x128/apps/main.png
# License: GPL-3
import base64

iconstr = b'''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==
'''


def thumbnail():
    icon = base64.decodestring(iconstr)
    return icon


if __name__ == '__main__':
    icon = thumbnail()
    f = open('thumbnail.png','wb')
    f.write(icon)
    f.close()
